@@ -1,9 +1,20 @@
+from typing import Tuple, Union
+
 from PIL import ImageFont
-from typing import Union, Tuple
 
 
 class Text:
-    """Text class for making multicolor text"""
+    """Text class
+
+    Parameters
+    ----------
+    text : str
+        Text
+    font : ImageFont.FreeTypeFont
+        Font for text
+    color : Union[Tuple[int, int, int], str, int], optional
+        Font color, by default "black"
+    """
 
     def __init__(
         self,
